Donations
==============

.. container:: admonition topic

  **If you like managesieve, please consider supporting me in some way.**


.. container:: box1

   .. centered:: Bank transfers

   While PayPal_ donations are still very much appreciated PayPal takes a
   large cut and has rather questionable business practices.

   If you have the ability to make SEPA bank transfers at a low cost (for
   example if you live within the EU) please contact `Hartmut
   <mailto:htgoebel@crazy-compilers.com>`_ to ask for his bank details.


.. container:: box2

   I trust in the power of free and open source software and thus made the
   entire source code publicly available for every one to use. However, it
   takes a lot of time to develop the software and manage the community. And I
   still need to make my living.

   So, if you like the software, please consider donating, especially if your
   organization benefits from this project.

   Thank you!


.. figure:: _images/bitcoin-managesieve.png
   :align: right
   :alt: QR-Code for Bitcoin address

   Bitcoin address

* **Bitcoin:** `13qryeeJR5Hc7vR5AmQMWDuLzDEgSDNJi2
  <bitcoin:13qryeeJR5Hc7vR5AmQMWDuLzDEgSDNJi2>`_

* **Bank-Transfer (prefered):**
  If you have the ability to make SEPA bank transfers at a low cost
  please `contact me <mailto:htgoebel@crazy-compilers.com>`_
  and I'll send you the account details.
  If you want a bill, please state so and also leave your name and address.

* **PayPal:** |PayPalDonate|_ - 
  if you want a bill, please state so and leave your name, address and
  email-address.

* Please `contact me <mailto:htgoebel@crazy-compilers.com>`_
  to arrange some kind of project grant, e.g. consulting or support.


.. |PayPalDonate| replace:: Donate
.. _PayPalDonate: PayPal_
.. _PayPal: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=6L5E5LMAW56CA

.. include:: _common_definitions.txt
